#!/usr/bin/perl
#
# Bind to the directory anonymous and search for an entry by the uid
# that is supplied on the command line.

use Stanford::Directory;
use strict;

##############################################################################
# Main Routine
##############################################################################

if (!$ARGV[0]) {
    die "Usage: $0 <some uid>\n";
}

my $UID = $ARGV[0];

my $dir = new Stanford::Directory;
$dir->set(basedn => 'cn=accounts,dc=stanford,dc=edu');

my @entries = $dir->ldap_query("uid=$UID");
if (!@entries) {
    # No entries were returned.  Display an error if that was the
    # cause otherwise just print a message say nothing was found.
    if ($dir->error) {
        my $msg = 'Error type:' . $dir->error_type . "\n";
        $msg .= 'Error:' . $dir->error . "\n";
        die $msg;
    } else {
        print "UID '$UID' not found in the directory\n";
    }
} else {
    # Only one entry is return, but it doesn't hurt to allow for
    # the odd case were the UID is not unique.  Print the common
    # names for the UID is they are available.
    for my $entry_ref (@entries) {
        my $this_uid = ($entry_ref->uid)[0];
        print "Search UID: $this_uid\n";
        print "Returned Attributes:\n";
        my %entry = %{$entry_ref};
        for my $attr (sort keys %entry) {
            my $val_ref = $entry{$attr};
            for my $val (@{$val_ref}) {
                print "   $attr:$val\n";
            }
        }
    }
}

exit;
