#!/usr/bin/perl
#
# This script uses an array of filters to select user entries by last
# name and displays the displayNames of the entries found.

use Stanford::Directory;
use strict;

##############################################################################
# Main Routine
##############################################################################

if (!$ARGV[0]) {
    die "Usage: $0 <some last name> [<host name]\n";
}
my $a_name = $ARGV[0];

my $host;
if ($ARGV[1]) {
    $host = $ARGV[1];
} else {
    $host = 'ldap.stanford.edu';
}

my $dir = new Stanford::Directory;
$dir->set(ldap_server => $host,
          mechanism   => "GSSAPI",
          basedn      => "cn=people, dc=stanford, dc=edu");

my @filter = ("sn=$a_name", "cn=$a_name");

print "Performing search ...\n";
my %entries = $dir->ldap_query(\@filter, 'displayname');
if (!%entries) {
    if ($dir->error) {
        my $msg = 'Error type:' . $dir->error_type . "\n";
        $msg .= 'Error:' . $dir->error . "\n";
        die $msg;
    } else {
        print "No match.\n";
    }
    exit;
}

print "People with last names like '$a_name':\n\n";
foreach my $key (keys %entries) {
    foreach my $ref (@{$entries{$key}}) {
        print '  ', $ref->displayname, "\n";
    }
}

exit;
