#!/usr/bin/perl
#
# Display attribute weights

use Stanford::Directory;
use strict;

##############################################################################
# Main Routine
##############################################################################

if (!$ARGV[0]) {
    die "Usage: test-weights.pl <some uid>\n";
}

my $uid = $ARGV[0];

my $dir = new Stanford::Directory;
$dir->set(
    ldap_server => "ldap.stanford.edu",
    mechanism   => "GSSAPI",
    basedn      => "cn=people,dc=stanford,dc=edu",
    weights     => 1
);

my @attrs = ('suOu', 'suAffiliation');
my @entries = $dir->ldap_query("uid=$uid", @attrs);
if (!@entries) {
    if ($dir->error) {
        my $msg = 'Error type:' . $dir->error_type . "\n";
        $msg .= 'Error:' . $dir->error . "\n";
        die $msg;
    } else {
        print "\n";
        print "UID '$uid' not found in the directory\n";
    }
} else {
    for my $entry_ref (@entries) {
        my $this_uid = ($entry_ref->uid)[0];
        print "Search UID: $this_uid\n";
        print "Returned Attributes:\n";
        my %entry = %{$entry_ref};
        for my $attr (sort keys %entry) {
            my $val_ref = $entry{$attr};
            for my $val (@{$val_ref}) {
                print "   $attr:$val\n";
            }
        }
    }
}

exit;
